package t::Sample::HasFeature;

use t::ToolSet::UseFeature;

my $foo;
my $bar;

sub hello {
    say "hello";
}

1; # return true
